package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````B!L``#0```#4H0````0`!30`(``)
M`"@`'0`<``$``'`0D0``$)$``!"1``#H````Z`````0````$````!@```#0`
M```T````-````"`!```@`0``!`````0````#````5`$``%0!``!4`0``&0``
M`!D````$`````0````$```````````````````#\D0``_)$```4`````$```
M`0```*2=``"DK0``I*T``*0"``"X`@``!@`````0```"````K)T``*RM``"L
MK0``(`$``"`!```&````!`````0```!P`0``<`$``'`!``!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DI)T`
M`*2M``"DK0``7`(``%P"```$`````0```"]L:6(O;&0M;&EN=7@M87)M:&8N
M<V\N,P`````$````%`````,```!'3E4`4GWB>#M4'W&673R&>H#$2[-Z>O@$
M````$`````$```!'3E4```````,````"`````````&$```!K````````````
M``!9````00``````````````"````````````````````#D`````````2@``
M`#@```!D`````````"L```!0````40```#(```!A````9P````,````O````
M```````````C````1@```"T``````````````%(```!)````-@```$T```!>
M````:@```"$````'````"0`````````8`````````#\```!B````3P```#,`
M````````3````&,````U````#0```#H``````````````%H````Q````2```
M`$4````J````````````````````/0```$,````````````````````6````
M#P`````````^````(@```"<```````````````H```!'````-P```#L```!4
M`````````"X```!I````0`````````````````````````!5`````````$(`
M``!7````*`````8````D````2P``````````````````````````````````
M````````````````````````````````````````````````````````````
M$`````````!6````````````````````````````````````%```````````
M````6``````````<`````````&4```!H`````````!\``````````````!D`
M````````9@``````````````&P````X````@````)@````0````,````'@``
M`"P``````````````!T```!.``````````````!3````)0```%P````:````
M`````!<````+````````````````````6P```#`````\````$P```$0```!=
M````````````````````````````````````!0```````````````````#0`
M```````````````````1````````````````````*0```!4`````````$@``
M``````````````````````!?````````````````````8```````````````
M$0```$T````(````"`````&0$`0E0`2`*(``!:"&4(2`@0`""R@$C#B`$D&*
M```(30```$X```!1````50```%8```!?````8````&$`````````8P```&0`
M``!E````9@```&<```!J```````````````!KS3H;L7?'\[>1RUK?YI\+L6;
MMM1DU'QV5#R4(?_D#MEQ6!SB1\8!L@&+;ZQ+X\!"^M>'PN4_+%COEWFZXY)\
M^J%L8)E/PYMK"4/69Z_,9D)%U>R)!W#3,V+;[16,)<P-.I<+?ZF<F^"G`@IJ
M&IY0O]I7&Z/@^TD``````````````````````````-`5`````````P`,````
M````L`````````,`&``3`@`````````````2````MP(`````````````$@``
M`&<``````````````!(```#(```````````````2````!0(`````````````
M$@```$\"`````````````!(```">`@`````````````2````?P``````````
M````$@```/("`````````````!(````!```````````````@````L@$`````
M````````$@```.D"`````````````!(````_`@`````````````2````,@,`
M````````````$@```$T!`````````````!(```#.`0`````````````2````
M$```````````````(````,\"`````````````!(````,`@`````````````2
M````O`(`````````````$@`````"`````````````!(```#!````````````
M```2````+```````````````(````+H``````````````!(```"E`0``````
M```````2````P0(`````````````$@```#$!`````````````!8````A`0``
M```````````2````!0,`````````````$@```!`!`````````````!(```#:
M`@`````````````2````V@``````````````$@```.\``````````````!(`
M``#6`0`````````````2`````@0`````````````$@```&(!````````````
M`!(```"Q```````````````1````.`(`````````````$@```#D#````````
M`````!$```#=`0`````````````2````J0(`````````````$@```/8`````
M`````````!(```"Y`0`````````````2````<`(`````````````$@```/@!
M`````````````!(```"7`@`````````````2````E@``````````````$@``
M`"H"`````````````!(```#``0`````````````2````_P``````````````
M$@```+D``````````````!(```!M```````````````2````6P(`````````
M````$@```)X!`````````````!(```"+`@`````````````2````1`$`````
M````````$@```*\``````````````!$```#Q`0`````````````1````%@,`
M````````````$0```-```````````````!(````C`P`````````````1````
MX0``````````````$@```*<``````````````!(````%`0`````````````2
M````B`$`````````````$@```)8!`````````````!(```!\`@``````````
M```2````1@``````````````$@```'$!`````````````!(```!;`0``````
M```````2````QP$`````````````$@```.P!`````````````!(````9`@``
M```````````2````6```````````````(@```%T$``!<L````````!``&0`+
M!```3$H``#P!```2``X`@@0``"A```!0!P``$@`.`%,```#`&```R`(``!(`
M#@""`P``1#(```0````2``X`H`,``'A'``#4`@``$@`.`#,$``!(L```````
M`!``&0"H!```2#(``)`"```2``X`:`0``$BP````````$``9`),#``#8-```
M,````!(`#@"V`P``]#L``*`````2``X`%P0``-!.```$````$0`0`$$$```0
M3```5`$``!(`#@!,!```V#```%0````2``X`5`0``%RP````````$``9`'T$
M``!<L````````!``&0"6!```\#X``#@!```2``X`OP0``)0\``!T````$@`.
M`"8$````L````````!``&`#:`P``"#4``*@!```2``X`CP0``$BP````````
M$``8`+4$``!$L```!````!$`&``L!```B!L````````2``X`=`0``(A+``"(
M````$@`.`"@$````L````````"``&`#P`P``S#X``"0````2``X`Q`,``"PQ
M```8`0``$@`.`.8#``!D30``4`$``!(`#@!<!```7+`````````0`!D`QP0`
M`+`V``!$!0``$@`.``!?7V=M;VY?<W1A<G1?7P!?251-7V1E<F5G:7-T97)4
M34-L;VYE5&%B;&4`7TE435]R96=I<W1E<E1-0VQO;F5486)L90!?7VQI8F-?
M<W1A<G1?;6%I;@!?7V-X85]F:6YA;&EZ90!A8F]R=`!?7W)E9VES=&5R7V%T
M9F]R:P!?7V%E86)I7W5N=VEN9%]C<'!?<'(P`%]?<W1A8VM?8VAK7V9A:6P`
M<W1R;F-M<`!?7V5N=FER;VX`;'-T870V-`!A8V-E<W,`;W!E;F1I<@!R96%D
M9&ER-C0`<W1R;&5N`%]?<W!R:6YT9E]C:&L`=6YL:6YK`&-L;W-E9&ER`')M
M9&ER`%!E<FQ?;F5W6%,`4&5R;%]N97=84U]F;&%G<P!B;V]T7T1Y;F%,;V%D
M97(`4$Q?8W5R<F5N=%]C;VYT97AT`')E861L:6YK`%!E<FQ?<W9?<V5T<'8`
M;65M8VAR`%!E<FQ?<W9?<V5T<'9N`%]?865A8FE?=6YW:6YD7V-P<%]P<C$`
M7U]M96UM;W9E7V-H:P!R96%L;&]C`&=E='!I9`!?7VUE;6-P>5]C:&L`<W1R
M8VAR`'-T<F1U<`!S=')T;VL`<W1R8VUP`'-T<G)C:'(`;65M8W!Y`%]?=F9P
M<FEN=&9?8VAK`&5X:70`<W1D97)R`&QS965K-C0`<F5A9`!M96UC;7``9V5T
M=6ED`&UK9&ER`%]?97)R;F]?;&]C871I;VX`7U]F<')I;G1F7V-H:P!O<&5N
M-C0`4&5R;%]G=E]F971C:'!V`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C
M;VYT97AT`%!E<FQ?;6=?<V5T`%!E<FQ?<WES7VEN:70S`%!E<FQ?<V%F97-Y
M<VUA;&QO8P!P97)L7W!A<G-E`'!E<FQ?9&5S=')U8W0`<&5R;%]F<F5E`%!E
M<FQ?<WES7W1E<FT`<&5R;%]A;&QO8P!P97)L7V-O;G-T<G5C=`!P97)L7W)U
M;@!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]A=&9O<FM?;&]C:P!03%]D;U]U
M;F1U;7``4$Q?;65M;W)Y7W=R87``;65M<V5T`%]?<W1A8VM?8VAK7V=U87)D
M`&QI8G!E<FPN<V\`;&EB8RYS;RXV`&QD+6QI;G5X+6%R;6AF+G-O+C,`;&EB
M9V-C7W,N<V\N,0!P87)?8W5R<F5N=%]E>&5C`'!A<E]B87-E;F%M90!84U])
M;G1E<FYA;'-?4$%27T)/3U0`<&%R7V5N=E]C;&5A;@!P87)?8W5R<F5N=%]E
M>&5C7W!R;V,`<&%R7V1I<FYA;64`<VAA7V9I;F%L`&=E=%]U<V5R;F%M95]F
M<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`%])3U]S=&1I;E]U<V5D`%]?9&%T
M85]S=&%R=`!?7V)S<U]S=&%R=%]?`'-H85]U<&1A=&4`>'-?:6YI=`!?7V5N
M9%]?`%]?8G-S7V5N9%]?`%]?8G-S7W-T87)T`'-H85]I;FET`%]E;F0`<&%R
M7VUK=&UP9&ER`%]E9&%T80!P87)?<V5T=7!?;&EB<&%T:`!P87)?9FEN9'!R
M;V<`;7E?<&%R7W!L`'!A<E]D:64`<&%R7VEN:71?96YV`$=,24)#7S(N-`!'
M0T-?,RXU`$=,24)#7S(N,S0`1TQ)0D-?,BXS,P`O=7-R+VQI8B]P97)L-2\U
M+C,X+C(O87)M=C=L+6QI;G5X+71H<F5A9"UM=6QT:2TV-&EN="]#3U)%````
M```````"``$``@`"``(``0`!``,``0`!``(``0`!``(``0`"``$``0`"``(`
M`@`"``$`!``"``$``0`!``$``0`!``(``@`"``(``0`"``(`!0`"``$``@`"
M``$``@`"``(``@`"``(`!``"``$``@`!``(``@`"``$``@`!``(``@`!``(`
M`@`!``8``P`"``(``@`"``(``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$````!``$`8`,``!``
M```@````%&EI#0``!0#4!`````````$``0!T`P``$````"````!5)GD+```#
M`-X$`````````0`#`%8#```0`````````+21E@8```8`Y@0``!````"SD98&
M```$`/$$```0````%&EI#0```@#4!````````*2M```7````J*T``!<```#\
MKP``%P````2P```7````%+```!<````8L```%P```""P```7````)+```!<`
M```HL```%P```"RP```7````,+```!<````XL```%P```#RP```7````1+``
M`!<```#(KP``%0L``,RO```5#```T*\``!43``#4KP``%1D``-BO```3'0``
MW*\``!4>``#@KP``%1\``.2O```5)P``Z*\``!4I``#LKP``%3P``/"O```5
M/0``]*\``!4_``#XKP``%4P``-BN```6`P``W*X``!8$``#@K@``%@4``.2N
M```6!@``Z*X``!8'``#LK@``%@@``/"N```6"0``]*X``!8,``#XK@``%@T`
M`/RN```6#@```*\``!8/```$KP``%A````BO```6$0``#*\``!82```0KP``
M%A0``!2O```6%0``&*\``!86```<KP``%A<``""O```6&```)*\``!8:```H
MKP``%AL``"RO```6'```,*\``!8@```TKP``%B$``#BO```6(@``/*\``!8C
M``!`KP``%B0``$2O```6)0``2*\``!8F``!,KP``%B@``%"O```6*@``5*\`
M`!8K``!8KP``%BP``%RO```6+0``8*\``!8N``!DKP``%B\``&BO```6,```
M;*\``!8Q``!PKP``%C(``'2O```6,P``>*\``!8T``!\KP``%C4``("O```6
M-@``A*\``!8W``"(KP``%C@``(RO```6.0``D*\``!8Z``"4KP``%CX``)BO
M```60```G*\``!9!``"@KP``%D(``*2O```60P``J*\``!9$``"LKP``%D4`
M`+"O```61@``M*\``!9(``"XKP``%DD``+RO```62@``P*\``!9+``#$KP``
M%DP```A`+>E\`0#K"("]Z`3@+>4$X)_E#N"/X`CPON7@F````,:/X@G*C.+@
M^+SE`,:/X@G*C.+8^+SE`,:/X@G*C.+0^+SE`,:/X@G*C.+(^+SE`,:/X@G*
MC.+`^+SE`,:/X@G*C.*X^+SE`,:/X@G*C.*P^+SE`,:/X@G*C.*H^+SE`,:/
MX@G*C.*@^+SE`,:/X@G*C.*8^+SE`,:/X@G*C.*0^+SE`,:/X@G*C.*(^+SE
M`,:/X@G*C.*`^+SE`,:/X@G*C.)X^+SE`,:/X@G*C.)P^+SE`,:/X@G*C.)H
M^+SE`,:/X@G*C.)@^+SE`,:/X@G*C.)8^+SE`,:/X@G*C.)0^+SE`,:/X@G*
MC.)(^+SE`,:/X@G*C.)`^+SE`,:/X@G*C.(X^+SE`,:/X@G*C.(P^+SE`,:/
MX@G*C.(H^+SE`,:/X@G*C.(@^+SE`,:/X@G*C.(8^+SE`,:/X@G*C.(0^+SE
M`,:/X@G*C.((^+SE`,:/X@G*C.(`^+SE`,:/X@G*C.+X][SE`,:/X@G*C.+P
M][SE`,:/X@G*C.+H][SE`,:/X@G*C.+@][SE`,:/X@G*C.+8][SE`,:/X@G*
MC.+0][SE`,:/X@G*C.+(][SE`,:/X@G*C.+`][SE`,:/X@G*C.*X][SE`,:/
MX@G*C.*P][SE`,:/X@G*C.*H][SE`,:/X@G*C.*@][SE`,:/X@G*C.*8][SE
M`,:/X@G*C.*0][SE`,:/X@G*C.*(][SE`,:/X@G*C.*`][SE`,:/X@G*C.)X
M][SE`,:/X@G*C.)P][SE`,:/X@G*C.)H][SE`,:/X@G*C.)@][SE`,:/X@G*
MC.)8][SE`,:/X@G*C.)0][SE`,:/X@G*C.)(][SE`,:/X@G*C.)`][SE`,:/
MX@G*C.(X][SE`,:/X@G*C.(P][SE`,:/X@G*C.(H][SE`,:/X@G*C.(@][SE
M`,:/X@G*C.(8][SE`,:/X@G*C.(0][SE`,:/X@G*C.((][SE`<J@XW!`+>D,
MP$W@R`^,Y5C"G^4HT$WB5#*?Y1P`C>48$(WE%""-Y0S`C^`#,)SG&!"-XA0@
MC>(<`(WB-%*?Y0`PD^4D,(WE`#"@X];__^LD(I_E!5"/X`(@E><<,I_E#""-
MY0,PE><"$*#A`P"@X1`PC>5>#0#K!#*?Y0,PE><`0-/E``!4XT\```IP+QWN
M\#&?Y1P`G>4#,)_G`T"`X@,@DN<$`(#BSC/2Y0<!<.,#,(/CSC/"Y6```(H`
M`:#AH?__ZP`PH.&\(9_E&!"=Y0(@C^``8)+EL,&?Y;!1G^6PX9_E'""=Y0``
MD>4,P(_@!5"/X`[@C^`!`%+C84"#Z`0PC.54``#:!`!!X@S`@^("`8#@!."Q
MY0$`4.$$X*SE^___&@/`@N(`X*#C:%&?Y6@1G^4%4(_@#`"5Y00@H.$`X(WE
M`1"/X`SA@^<)___K``!0XRD```I$49_E(&"-X@50C^`,`)7E3?__ZP!`H.$P
M`9_E!A"@X0``C^#2`P#K``!0XR````H<,9_E`S"/X`P`D^7H_O_K(___ZPPA
MG^7,,)_E`B"/X`,PDN<`()/E)#"=Y0(@,^``,*#C*@``&@0`H.$HT(WB<("]
MZ`'__^O<()_E``!0XP(@C^`,`(+E'P``"A;__^MP+QWNQ#"?Y0,PG^<#,)+G
MKD;#Y:/__^H,`)7EY/[_Z]+__^H(`)7E``!0XP$```K;"P#KV?__ZI0`G^4&
M$*#A``"/X*8#`.L``%#C"`"%Y=+__PKU___J>#"?Y7@`G^4#,)7G``"/X`,0
MH.$,,(WE-?__ZP3`H..P___J`0"@XUO__^L>___KW)4``!P!``"PE0``_```
M`!0!```D`0``>)8``*R6``"8E@``S#@``,PX``!0E@``H!(``"26``#H-0``
M^)4``&"4``"LE0``()4``-0T```H`0``L#8```"PH.,`X*#C!!"=Y`T@H.$$
M("WE!``MY1R@G^48,(_B`Z"*X``PH.,$,"WE#`"?Y0``FN<M___KD/[_ZPB3
M```P`0``%#"?Y10@G^4#,(_@`B"3YP``4N,>_R\!EO[_ZO"2`````0``+`"?
MY2PPG^4L()_E``"/X`,PC^```%/A`B"/X![_+P$8,)_E`S"2YP``4^,>_R\!
M$_\OX424``!`E```O)(```0!```X`)_E.#"?Y0``C^`#,(_@`#!#X*,?H.$H
M()_E0Q&!X,$0L.$"((_@'O\O`1@PG^4#,)+G``!3XQ[_+P$3_R_A!)0```"4
M``!LD@``"`$``%@PG^58()_E`S"/X``PT^4"((_@``!3XQ[_+Q$!RJ#C$$`M
MZ0S`3>#X#XSE-#"?Y0,PDN<``%/C`@``"B@PG^4#`)_G^?[_Z\?__^L!(*#C
M&#"?Y0,PC^``(,/E$("]Z+23```PD@``+`$``#B3``!HDP``S?__Z@`````!
MRJ#C\$\MZ0S`3>!`#8SE:"R?Y6@\G^4"((_@`S"2YZ??3>(`$*#A$,"-X@`P
MD^64,HWE`#"@XPP@H.$`0*#C0`"`XH!0@>)`0!#I+C2@X?\\`^(.=*#A+CR#
MX0@`@.+_>`?B#CR#X39OO^8',(/A!0!0X01`@N4`8(+E"#""Y0Q`@N40((+B
M[O__&H(_C.(<0)WE>,"=Y00PC>6(,)WE&%"-X@@0C>4%`*#A`Q"@X0R0H.%\
M()WE&+"=Y8"`G>6$<)WEC."=Y1!@G>44H)WE`$"-Y0Q0C>4!``#J!;"@X0!`
MC>4`0*#C`3"@X3S`D.4X$)#E"%"PY71`@.4$0)#E!1`AX`D0(>`$P"S@!A`A
MX`+`+.`*P"S@")"@X0.`H.&A/Z#AC#"#X0$0D>`#$('A!#"=Y0<@H.$``%/A
M#G"@X0M@H.$`X*#C`*"=Y7`0@.7A__\:F3D'XP@0G>4,4)WE"`"1Y0`4D>@(
M0!7E#."1Y8(Z1>,0D)'E&+"1Y:HMH.$@`:#A*F&@X8PB@N$.#X#A#&^&X0C@
MD>4#P)3@($"1Y0MP*>`.#X#A&("=Y03`G.`.<`?@BB*"X0MP)^``X"G@#""2
MX`=`DN`*X`[@`R"8X`G@+N`+()+@"F^&X0[`DN`(()7E!N`@X`,@DN`$X`[@
M`.`NX`D@DN#DS8S@#B"2X.Q]@N`0()7E&."5Y0,@DN``()+@9`$FX`P``.`&
M`"#@;,&@X0``DN`#X)[@!N">X&1A+.`'8`;@9&$FX.<-@.`&X)[@X&V.X"#@
ME>6A*P[C`^">X&3ACN!G02S@`$`$X`Q`).`$X)[@*$"5Y6`!H.$#0)3@#,"4
MX&=!(.`&0`3@9T$DX.;MCN`$P)S@[DV,X##`E>79+D;C`\"<X&?!C.!F<2#@
M#G`'X`!P)^`'P)S@.'"5Y6[AH.$#<)?@``"7X&9Q+N`$<`?@9G$GX.3-C.`'
M`)#@['V`X$``E>4#`)#@9@&`X&1A+N`,8`;@#F`FX`8`D.#G;8#@2`"5Y6S!
MH.$#`)#@#@"0X&3A+.`'X`[@9.$NX`X`D.#F[8#@4`"5Y0,`D.!D`8#@9T$L
MX`9`!.`,0"3@!`"0X.Y-@.!8`)7E9F&@X0,`D.`,`)#@9\$FX`[`#.!GP2S@
M#`"0X.3-@.!@`)7E`P"0X&<!@.!N<2;@!'`'X`9P)^`'`)#@['V`X&@`E>5D
M0:#A`P"0X`8`D.!N823@#&`&X&YA)N`&`)#@YVV`X'``E>4#`)#@;@&`X&SA
M).`'X`[@!.`NX`X`D.#F[8#@>`"5Y6=QH.$#`)#@!`"0X&Q!)^`&0`3@;$$D
MX`0`D.#N38#@@`"5Y0,`D.!L`8#@9L$GX`[`#.`'P"S@#`"0X(C`E>5NX:#A
M`\"<X`?`G.!F<2[@!'`'X&9Q)^`'P)S@D'"5Y>0-@.`#,)?@9C&#X&1A+N``
M8`;@#F`FX`8PD^"88)7EX,V,X`)@EN!@`:#AH'"5Y0[@EN!D82#@#&`FX`;@
MGN`"8)?@[#V#X*APE>5D88;@;$$@X`-`).#C[8[@!&"6X&,QH.$"0)?@``"4
MX+!PE>5L02/@#D`DX`1`D.`"`)?@[FV&X&P!@.!NP2/@N'"5Y0;`+.`,`)#@
M9L&@X>9-A.#`@)7E`F"7X&YQ+.`$<"?@`V"6X.0-@.`'8);@`G"8X&[AA^#(
M@)7EX'V&X&1A+.``8";@!N">X&`!H.$"8)C@#,"6X-"`E>5D82#@!V`FX`9@
MG.`"P)C@Y^V.X-B`E>5DP8S@9T$@X`Y`).#N;8;@!,"<X&[AH.$"0)C@``"4
MX."`E>5G02[@!D`DX`1`D.#</`OC`@"8X.;-C.#H@)7E9P&`X&9Q+N`,<"?@
M[$V$X`<`D.!LP:#A`G"8X`YPE^#P@)7E^."5Y691+.`$4"7@Y`V`X`50E^#@
M?87@`H"8X&11+.!F88C@`%`EX`50EN!@`:#A`N">X!AAG>4,P)[@9.$@X`?@
M+N#G787@#L"<X`+@EN!DX8[@Y6V,X"!!G>5GP2#@!<`LX`S@GN!EP:#A`D"4
MX"A1G>4``)3@9T$LX`9`).`$0)#@`@"5X.;MCN!F42S@9P&`X#!QG>4.4"7@
M[DV$X`4`D.!NX:#A`E"7X`Q0E>`X<9WEY,V`X&8!+N`$`"#@``"5X`)0E^!F
M487@0'&=Y61A+N`,8";@[`V`X`90E>!LP:#A`F"7X`Y@EN!(<9WE9.$LX`#@
M+N#@787@#N"6X`(@E^!D(8+@4'&=Y>5-CN!@X2S@&S](XV5AH.$%X"[@#B"2
MX`-PE^!@X8;A8%$&X`S`E^`$X`[@6'&=Y07@CN$.X)S@`\"7X.0M@N!@P8S@
M9`&&X611!N!@<9WE`@``X.+MCN`%`(#A8B&@X611@N$,P)#@`P"7X`8`D.!H
M<9WE9&$"X`Y0!>`&4(7A[LV,X`!0E>`#<)?@;@&"X>QMA>!D08?@;E$"X'!Q
MG>4,``#@;,&@X04`@.%N48SA>(&=Y00`D.`&4`7@`T"7X&YQ#.`"0)3@!U"%
MX010E>`#0)C@Y@V`X&Y!A.!FX8SA9G$,X("!G>4`X`[@!^".X>!=A>`$0)[@
M8`&@X0/@F.`,X)[@Y<V$X&9!@.%F<0#@B(&=Y05`!.`'0(3A#D"4X`/@F.!F
M88[@9>&`X65Q`."0@9WE#.`.X`?@CN'L383@!F">X&S!H.$#X)C@`.">X.0-
MAN!E88SA97$,X)B!G>4$8`;@!V"&X0[@EN`#8)C@96&&X&11C.%D<0S@H(&=
MY0!0!>`'4(7AX.V.X`9@E>!@`:#A`U"8X`Q0E>#NS8;@9&&`X61Q`."H@9WE
M#F`&X`=@AN$%4);@`V"8X&1AAN!N08#A;G$`X+"!G>4,0`3@!T"$X>Q=A>`&
M8)3@;,&@X0-`F.``0)3@Y0V&X&YAC.%N<0S@N(&=Y05@!N`'8(;A!&"6X`-`
MF.!N083@9>&,X<"!G>5E<0S@`.`.X`?@CN'@;8;@!.">X&`!H.$#0)C@#,"4
MX&5!@.%E<0#@R(&=Y09`!.`'0(3A#$"4X`/`F.#F[8[@95&,X&;!@.%F<0#@
M#L`,X`?`C.$`<*#CUB$,X]"!G>7N383@!5"<X&[AH.$#P)C@`,"<X.0-A>!F
M48[AV(&=Y010!>`$<('E#'"!Y11P@>4<<('E9G$.X`=0A>$,4)7@`\"8X&9A
MC.!DP8[A9'$.X."!G>4`P`S@!\",X>!=A>`&P)S@8`&@X0-@F.`.8);@9.&`
MX61Q`.#H@9WE!>`.X`?@CN'ES8S@!N">X`.`F.!E,8#A96$`X`PP`^#P<9WE
M9$&(X`8P@^%B*DSC[.V.X`0PD^!LP:#A[DV#X/AAG>4"<)?@93$LX```E^`.
M,"/@`S"0X`(`EN!E`8#@`&*=Y>1=@^!N,2S@!#`CX`,PD.!D0:#A`F"6X`S`
MEN!N`23@"&*=Y04`(.#E/8/@``"<X`+`EN!NP8S@$&*=Y>/M@.!E`23@`P`@
MX```G.!C,:#A`F"6X`1`EN!EP2/@&&*=Y0[`+.#N#8#@#,"4X`)`EN!E083@
M(&*=Y>!=C.!NP2/@`,`LX`S`E.!@`:#A`D"6X`-`E.`H8IWE;C$@X`4P(^#E
MS8S@`S"4X`)@EN#L38/@;N&&X&4Q(.`P8IWE##`CX`,PGN!LP:#A`N"6X`#@
MGN`X8IWE90$LX`0`(.#D/8/@``">X`+@EN!EX8[@0&*=Y>-=@.!D`2S@`P`@
MX```GN!C,:#A`N"6X`S@GN!(8IWE9,$CX`7`+.#E#8#@#,">X`+@EN!DX8[@
M4&*=Y>!-C.``<*#C9<$CX`#`+.`,P)[@8`&@X0+@EN`#X)[@6&*=Y64Q(.`$
M,"/@Y,V,X`,PGN`"X);@9>&.X&!BG>7L78/@9#$@X`PP(^`#,)[@;,&@X0+@
MEN``X)[@:&*=Y60!+.`%`"#@Y3V#X```GN`"X);@9.&.X'!BG>7C38#@90$L
MX`,`(.```)[@8S&@X0+@EN`,X)[@>&*=Y67!(^`$P"S@#,">X`+@EN#D#8#@
M9>&.X&1A(^"`4IWE`&`FX.#-C.`&X)[@8`&@X0)0E>`#,)7@9&$@X(A2G>4,
M8";@!C"3X`(@E>#L[8[@;+&+X`H@DN!LP2#@#L`LX&Z1B>!D(8+@#""2X!BP
M@>40D('E","1Y>X]@^`,P)/@XSV"X"`@D>4`,('E`@"0X#P@G^4T,)_E`B"/
MX`C`@>4@`('E)'"!Y0,PDN<`()/EE#*=Y0(@,^``,*#C`0``&J??C>+PC[WH
MBOO_ZZR1```<`0``>(4```'*H./P1RWI#,!-X.`/C.7(,)_E`(!0X@,PC^`K
M```*O""?Y0(PD^<`D)/E``!9XR@```H`4-CE`7"@X0``5>,]`%43`5"@$P!0
MH`,1```:`$"9Y0``5.,,```*"6"@X04@H.$($*#A!`"@X8_[_^L``%#C`@``
M&@4PU.<]`%/C"P``"@1`MN4``%3C\___&@0`H.'PA[WH"%"@X0$P]>4``%/C
M/0!3$_O__QH(4$7@YO__Z@E@1N`!4(7B1F&@X05`A.`$`*#A`&"'Y?"'O>@(
M0*#A[?__Z@E`H.'K___J((4``!@!```!RJ#C$$`MZ0S`3>"(#XSEC""?Y8PP
MG^4"((_@<-!-X@,PDN<-$*#A`#"3Y6PPC>4`,*#C`$"@X4K[_^L``%#C``"@
M$P0``!H0,)WE#SH#X@H*4^,!"5,3"@``"D@@G^5`,)_E`B"/X`,PDN<`()/E
M;#"=Y0(@,^``,*#C!P``&G#0C>(0@+WH`A"@XP0`H.'O^O_K$`]OX:`"H.'N
M___J)/O_ZSB$```<`0``[(,```'*H./P0"WI#,!-X'`/C.5@(9_E8#&?Y0(@
MC^`#,)+G?-!-X@!04.(`,)/E=#"-Y0`PH.,"```*`##5Y0``4^,*```:-"&?
MY2PQG^4"((_@`S"2YP`@D^5T,)WE`B`SX``PH.-"```:?-"-XO"`O>B>^O_K
M`&!0XO'__PH&`*#A'OO_ZP``4.,K```*$S#0Y1-`@.(N`%/C`@``&@$PU.4`
M`%/C]/__"A,PT.4N`%/C)@``"@4`H.'+^O_K`'"@X00`H.'(^O_K`'"'X`)P
MA^('`*#AZ/K_ZP1`C>4`0*#AG#"?Y0<@H.$"$*#C`S"/X`!0C>4$^__K!`"@
MX0@0C>*J^O_K`0!PXP0`H.$#```*&#"=Y0\Z`^(!"5/C$@``"K3Z_^L$`*#A
ME_K_ZP8`H.'R^O_K``!0X]/__QH&`*#AP?K_ZP4`H.'7^O_KO/__Z@$PU.4N
M`%/CU?__&@(PU.4``%/CQ/__"M'__^JC___KZ___ZL/Z_^N(@P``'`$``%2#
M``!,(P```<J@XQ!`+>D,P$W@Z`^,Y7!/'>YH()_E:!"?Y0(@C^`!()+G$-!-
MXEP`G^4,((WE``"?YU0PG^54$)_E``"4YP,PC^`!$(_@T_K_ZP#`H.-``)_E
M0#"?Y0``G^<\()_E/!"?Y0,PC^```)3G`B"/X`@0C>@!$(_@<_K_ZQ#0C>(0
M@+WH_($``!`!``#T@@``,&,``'0B``#,@@``:"4``%@:``!@(@```<J@X_!!
M+>D,P$W@``",Y2``#.4!<*#A`!&?Y0':3>+\,)_E"-!-X@$0C^`#,)'G`&"@
MX0$*C>($`(#B`#"3Y0`P@.4`,*#CV`"?Y02`C>+_+P#C"!"@X0``C^"8^O_K
M`$!0X@<``-H(4(WB`3!$X@/`A>`$(%SE``!2XQ<``!H``%/C%```&G`/'>Z8
M,)_E!R"@X0,PG^<&$*#A`P"0YR'Z_^N$()_E=#"?Y0(@C^`!&HWB`S"2YP00
M@>(`()/E`#"1Y0(@,^``,*#C$@``&@':C>((T(WB\(&]Z`-`H.$$(*#A+Q"@
MXP@`H.&/^O_K``!0X^/__PIPSQWN,`"?Y00PH.$``)_G"""@X080H.$``)SG
M-/K_Z^'__^I-^O_K2($``!P!``#L(0``Z($``,2```!X@0```<J@X_!/+>D,
MP$W@T`^,Y0%`H.$8(I_E&#*?Y0(@C^`#,)+G#-!-X@`PD^4$,(WE`#"@XP`P
MT>4`4*#A/0!3XP%`@0($`*#A#?K_ZPT0H.$`8*#A!0"@X:C^_^O8<9_E`)!0
MX@=PC^!````*!/K_ZP``5N$W``":P#&?Y0"`G>4#<)?G"(&@X0`PU>4``%/C
M/0!3$P$PH!,`,*`#!0``"@4PH.$!(//E``!2XST`4A/[__\:!3!#X`(`AN(#
M`(#@`&"7Y1+Z_^L``%#C"`"&YQ4```H%`*#A`#"7Y0@0D^<!,-#D/0!3XP``
M4Q,`,,'E!@``"@$@@>(!,-#D`A"@X0``4^,]`%,3`3#"Y/G__QH],*#C`2"@
MX0`PP>4!,-3D``!3XP$PXN7[__\:$"&?Y0`QG^4"((_@`S"2YP`@D^4$,)WE
M`B`SX``PH.,W```:#-"-XO"/O>@!D$GB`3#4Y```4^,!,.GE^___&N[__^K(
M,)_E`W"7YP"`E^4`,)CE``!3XR8```H(,*#A!""SY0D0H.$``%+C`9")XOK_
M_QH#$('B`;&@X9@PG^4#,(_@`""3Y0``4N,0```:`2"@XPL`H.$`((/ET?G_
MZP"@4.+5__\*"!"@X0F!H.$+,*#A"""@X??Y_^L`H(?E`#"@XP"0C>4!D(GB
M"3&*YZ'__^H+$*#A"`"@X?'Y_^L``%#C`*"@X0``A^7#__\*"8&@X?'__^H#
MD*#A"+"@X]W__^JZ^?_K'(```!P!``#4?P``&`$```1_```,@```<`\=[C0@
MG^4TP)_E`B"/X`P@DN<(T$WB*!"?Y00@C>4!$)_G(#"?Y0$`D.<<$)_E`S"/
MX`$0C^`(T(WBR_G_ZN!]```0`0``V'X``!1?``!8'@```<J@X_!`+>D,P$W@
M``",Y0'*3.(``(SE,``,Y>`@G^4"VDWBW#"?Y1S03>("((_@`S"2YP(:C>(4
M$('B`#"3Y0`P@>4`,*#CH?G_Z[C`G^6X,)_E`4J-X@S`C^`00(3B`1"-Z`$@
M`>,"$*#C!`"@X0,PC^`,8(WBH?G_ZP0`H.$!*J#C!A"@X9?Y_^L`0%#B`%"@
MLPH``+H!<(3B!P"@X7/Y_^L`4%#B!0``"@<PH.$&$*#A!""@X3WY_^L`,*#C
M!##%YT@@G^4X,)_E`B"/X`(:C>(#,)+G%!"!X@`@D^4`,)'E`B`SX``PH.,#
M```:!0"@X0+:C>(<T(WB\("]Z%[Y_^ML?0``'`$``#`>```,'@``S'P``+C_
M_^H!RJ#C\$\MZ0S`3>```(SEJ``,Y43"G^5"W4WB0"*?Y0303>(,P(_@`&"@
MX30"G^4"()SG03V-XA"`C>(!0*#A``"/X`@0H.$\,(/B`""2Y0`@@^4`(*#C
MN?W_ZR\0H.,`4*#A!@"@X>;X_^L``%#C$@``"O`!G^4&$*#A``"/X._^_^L&
M`*#AX"&?Y=`QG^4"((_@01V-X@,PDN<\$('B`""3Y0`PD>4"(#/@`#"@XVD`
M`!I"W8WB!-"-XO"/O>@$`*#A&OG_ZZ01G^4!$(_@*?G_ZP!`4.+E__\*`##4
MY9"1G^6`H(WB``!3XPF0C^`$<$KB.P``"@``5>,$```*!!"@X04`H.%.^?_K
M``!0XRL```H$`*#AZOC_ZP$P0.(#,(3@`P!4X0"PH.$`P*`S`#"$,`$0A#(#
M```Z"```Z@,`4>$`P,/E`@``"@$@<^4O`%+C^?__"@0`H.'9^/_K`+"@X08`
MH.'6^/_K"P"`X`$`@.(!"E#CO?__*O@`G^4),*#A``"/X`$JH.,"$*#C00"-
MZ0!`C>4'`*#A$?G_ZP@0H.$'`*#AM_C_ZP``4.,#```:8#`:Y0\Z`^(""5/C
M%0``"K00G^4``*#C`1"/X.GX_^L`0%#BI?__"@`PU.4``%/CP___&@``5>,6
M```*`##5Y2X`4^,#```*@$"?Y0&PH.,$0(_@U?__Z@$PU>4``%/CZO__"O?_
M_^H!$*#C!P"@X97X_^L``%#CY/__&E``G^4'$*#A``"/X(#^_^L'`*#ANOC_
MZX[__^HX0)_E`;"@XP1`C^#!___JP/C_ZUA\```<`0``-!T```0=``#L>P``
MQ!P``*@<```8'```Q!L``&P;``!(&P``'!L```'*H.,00"WI#,!-X/@/C.4O
M$*#C`$"@X67X_^L``%#C`4"`$@0`H.$00+WHG/C_Z@'*H.-P0"WI#,!-X```
MC.48``SE<"&?Y0':3>)L,9_E"-!-X@(@C^`!&HWB`S"2YP!@4.($$('B`#"3
MY0`P@>4`,*#C+P``"@`PUN4``%/C+```"FOX_^L!((#B`0I2XP!`H.$X``"*
M!%"-X@80H.$%`*#A:?C_ZP$P1.(#,(7@!0!3X0<``)H`$*#C`@``Z@4`4^$!
M$,/E`@``"@$@4^0O`%+C^?__"B\0H.,%`*#A,_C_ZP``4.,E```*!0!0X0`P
MH(,`,,"%!0"@X6CX_^N\()_EM#"?Y0(@C^`!&HWB`S"2YP00@>(`()/E`#"1
MY0(@,^``,*#C(@``&@':C>((T(WB<("]Z(@@G^5\,)_E`B"/X`$:C>(#,)+G
M!!"!X@`@D^4`,)'E`B`SX``PH.,4```:8`"?Y0``C^`!VHWB"-"-XG!`O>A)
M^/_J``"@X][__^I$()_E,#"?Y0(@C^`!&HWB`S"2YP00@>(`()/E`#"1Y0(@
M,^``,*#C(`"?!0``CP#L__\*1?C_ZYAY```<`0``Y'@``*QX``!X&0``8'@`
M`#`9```!RJ#C<$`MZ0S`3>#H#XSEQ"2?Y<0TG^4"((_@P%2?Y0,PDN>\9)_E
M"-!-X@50C^``,)/E!#"-Y0`PH.,&8(_@#4"@X000H.$&`*#AHOS_ZP``4.,.
M```*C#2?Y0`0G>4#,)7G`""3Y0$Q@N`$`)/E``!0XP$!@N?Q__\*!#"#X@0@
MD^4``%+C!""#Y/O__QKK___J5&2?Y09@C^`$$*#A!@"@X8S\_^L``%#C#@``
M"C0TG^4`$)WE`S"5YP`@D^4!,8+@!`"3Y0``4.,!`8+G\?__"@0P@^($()/E
M``!2XP0@@^3[__\:Z___Z@!DG^4&8(_@!!"@X08`H.%V_/_K``!0XPX```K<
M,Y_E`!"=Y0,PE><`()/E`3&"X`0`D^4``%#C`0&"Y_'__PH$,(/B!""3Y0``
M4N,$((/D^___&NO__^JL8Y_E!F"/X`00H.$&`*#A8/S_ZP``4.,.```*A#.?
MY0`0G>4#,)7G`""3Y0$Q@N`$`)/E``!0XP$!@N?Q__\*!#"#X@0@D^4``%+C
M!""#Y/O__QKK___J6&.?Y09@C^`$$*#A!@"@X4K\_^L``%#C#@``"BPSG^4`
M$)WE`S"5YP`@D^4!,8+@!`"3Y0``4.,!`8+G\?__"@0P@^($()/E``!2XP0@
M@^3[__\:Z___Z@1CG^4&8(_@!!"@X08`H.$T_/_K``!0XPX```K4,I_E`!"=
MY0,PE><`()/E`3&"X`0`D^4``%#C`0&"Y_'__PH$,(/B!""3Y0``4N,$((/D
M^___&NO__^JP8I_E!F"/X`00H.$&`*#A'OS_ZP``4.,.```*?#*?Y0`0G>4#
M,)7G`""3Y0$Q@N`$`)/E``!0XP$!@N?Q__\*!#"#X@0@D^4``%+C!""#Y/O_
M_QKK___J7&*?Y09@C^`$$*#A!@"@X0C\_^L``%#C#@``"B0RG^4`$)WE`S"5
MYP`@D^4!,8+@!`"3Y0``4.,!`8+G\?__"@0P@^($()/E``!2XP0@@^3[__\:
MZ___Z@ABG^4&8(_@!!"@X08`H.'R^__K``!0XPX```K,,9_E`!"=Y0,PE><`
M()/E`3&"X`0`D^4``%#C`0&"Y_'__PH$,(/B!""3Y0``4N,$((/D^___&NO_
M_^JT89_E!F"/X`00H.$&`*#AW/O_ZP``4.,.```*=#&?Y0`0G>4#,)7G`""3
MY0$Q@N`$`)/E``!0XP$!@N?Q__\*!#"#X@0@D^4``%+C!""#Y/O__QKK___J
M8&&?Y09@C^`$$*#A!@"@X<;[_^L``%#C#@``"APQG^4`$)WE`S"5YP`@D^4!
M,8+@!`"3Y0``4.,!`8+G\?__"@0P@^($()/E``!2XP0@@^3[__\:Z___Z@P!
MG^4$$*#A``"/X+'[_^L`$%#B`@``"O@`G^4``(_@[/S_Z_``G^4$$*#A``"/
MX*C[_^L`$%#B`@``"MP`G^4``(_@X_S_Z]0`G^4$$*#A``"/X)_[_^L`$%#B
M$@``"L``G^4``(_@VOS_Z[@@G^5D,)_E`B"/X`,PDN<`()/E!#"=Y0(@,^``
M,*#C$```&I@0G^68`)_E`1"/X```C^`(T(WB<$"]Z,K\_^J$`)_E!!"@X0``
MC^"&^__K`!!0XNG__PIP`)_E``"/X,'\_^OE___J!_?_Z_QW```<`0``Z'<`
M`/P8```8`0``K!@``%P8```0&```P!<``'@7``"\%@``U!8``(@6```\%@``
M:!4``)05``!H%0``A!4``(05``"`%0``I!0``)QS``!<%0``P!0``"P5``"P
M%````<J@XP3@+>4,P$W@\`^,Y7@@G^5X,)_E`B"/X'0`G^4,T$WB`S"2YPT0
MH.$``(_@`#"3Y00PC>4`,*#C5?O_ZP``4.,%```*``#0Y0``4.,P`%`3`0"@
M`P``H!,!`"#B-""?Y2@PG^4"((_@`S"2YP`@D^4$,)WE`B`SX``PH.,!```:
M#-"-X@3PG>3)]O_KN'(``!P!```,%```:'(```'*H.,/`"WI!.`MY0S`3>#P
M#XSE2""?Y4@PG^4"((_@`S"2YPS03>(`,)/E!#"-Y0`PH.,P`)_E,,"?Y10P
MC>(``(_@`#"-Y0P`D.<"$*#C$""=Y0``D.69]O_K_P"@X^CV_^L4<@``'`$`
M`/!Q```@`0```,"@X_!'+>D!Z*#C#,!-X`[@3.`!RDSB``",Y0X`7.'[__\:
M.``.Y0(0H.-XX9_E`=A-XG3!G^48T$WB#N"/X`S`GN<!2(WB`""@XP`PH.,`
MP)SE%,"$Y0#`H.,`$(WE`("@X8CV_^L!`%#B`'#!XL<OH.''/R#@`C!3X',P
M_^8","/@`C!3X`(@PN`#8%#@`G#'X```5^,40(3B.```N@B0H.,,4(WB`9!`
MXP`0H.,&(*#A!S"@X0@`H.$`$(WE<?;_ZP$`<>,!`'`#,@``"@D@H.$%$*#A
M"`"@X33V_^L!`'#C*0``"@<`4.,?``":"`!`X@!`E>`<```JL*"?Y0J@C^`"
M``#J`4!$X@4`5.$6```Z"""@XPH0H.$$`*#A_/7_ZP``4./V__\:!4!$X`8`
ME.#$'Z?@>""?Y6PPG^4"((_@`<B-X@,PDN<4P(SB`""3Y0`PG.4"(#/@`#"@
MXQ```!H!V(WB&-"-XO"'O>@!:%;B`'#'X@$`=^,!"'8#R?__&@``X.,`$*#A
MZ?__ZB0`G^4``(_@>___ZQP`G^4``(_@>/__ZSWV_^N`<0``'`$``/AQ``!\
M<```(!(```02```!RJ#C$$`MZ0S`3>#X#XSE\/7_ZQ/V_^L``%#C``"0%1"`
MO>@!RJ#C\$`MZ0S`3>#0#XSE`"&?Y0!QG^4`,9_E`B"/X!S03>(#,)+G!W"/
MX`!0H.$0$(WB!P"@X0`PD^44,(WE`#"@XY3Z_^L`0%#B`@``"@`PU.4``%/C
M#@``&L`@G^6X,)_E`B"/X`,PDN<`()/E%#"=Y0(@,^``,*#C)```&@40H.&<
M`)_E``"/X!S0C>+P0+WHP/O_Z@4`H.'?]?_K`&"@X00`H.'<]?_K`&"&X`)@
MAN(&`*#A_/7_ZV@0G^5H,)_E`1"/X`8@H.$(0(WE`S"/X`00C>4`4(WE`A"@
MXP!`H.$5]O_K1""?Y2PPG^4"((_@`S"2YP`@D^44,)WE`B`SX``PH.,$$*`!
M!P"@`=W__PKH]?_KN&\``+`1```<`0``<&\``%`1```D$```'!```.1N```!
MRJ#C\$\MZ0S`3>#@#HSEM.:?Y?S03>(.X(_@L$"-XB#@C>4$X*#AH!:?Y:#&
MG^6@)I_E`1"/X`(@D><,P(_@##",XAA@C.*D<(WB`""2Y?0@C>4`(*#C'`"-
MY0<`D^@'`(?H#P"VZ`\`KN@#`);H,,",XIA0C>(#`([H!P"<Z`<`A>A0!I_E
M*("-X@@0H.$``(_@,OK_ZP!@4.("```*`##6Y0``4^,I`0`:<O7_ZY7U_^L`
M`%#CB```"@!@D.4``%;CA0``"@8`H.&%]?_K@""@X0&P@N(+`*#AI?7_ZP#`
MUN4`4*#A``!<XPN0H!$D`(T5)`$`"N"EG^4*H(_@"R"@X0HPH.$"$*#C!0"@
MX0#`C>6[]?_K"P!9X0D@H"$+(*`Q`C!+X@L00N`!P/;E`C!#X`(0@>("`%'A
M`;"#(`*P@S```%SC`E"%XNO__QJ,!9_E``"/X`(``.H$`+3E``!0XPT```H(
M$*#A_/G_ZP!04.+X__\*`##5Y0``4^/U__\*,/K_ZP``4./R__\*!0"@X6[U
M_^L`0%#B#0``&@1`E^0``%3C"@``"@`PU.4``%/CTP``"@0`H.$B^O_K``!0
MX_7__PH$`*#A8/7_ZP!`4.+Q__\*!`"@X4'U_^LD4)WE`&"@X04`H.$]]?_K
M`&"&X`%KAN($8(;B!@"@X5SU_^L`<*#AV#2?Y08@H.$#,(_@"#"-Y<PTG^4"
M$*#C`S"/X`0PC>7`-)_E#%"-Y0,PC^``0(WE<O7_ZP<=H.,'`*#AW_3_ZP$`
M<.,#```:BO7_ZP``D.41`%#CKP``&@@0H.$'`*#A4?7_ZP!`4.(Q```*>`2?
MY2#`G>4<,)WE``"<YVPDG^4`,)/E`'"-Y0(0H.,``)#E`B"/X#OU_^L`4*#C
M4"2?Y2@TG^4"((_@`S"2YP`@D^7T,)WE`B`SX``PH./\```:!0"@X?S0C>+P
MC[WH'O7_ZP!@4.*+```:!`"5Y```4.,)```*"!"@X9OY_^L`,%#B^/__"@`P
MT^4``%/C\O__&@0`E>0``%#C]?__&@T`H.,6]?_K#9"@X]ACG^53P*#C`%"@
MX0FPH.$&8(_@)`"-Y6[__^HX,)WE#SH#X@$)4^/)__\:0%"=Y<GT_^L``%7A
MQ?__&C@PG>53,.CG!PU3X\'__QH&`*#A`/7_ZP!0H.&$`Y_E"!"@X0``C^!V
M^?_K`!!0XH````H<,)WE``"3Y:#[_^L`H%#B>P``"@H`H.'.]/_K`P!0XP"0
MH.$,``":2!.?Y00`0.(``(K@`1"/X";U_^L``%#C!0``&@0`6>.G```*"9"*
MX`4P6>4O`%/CHP``"A@#G^4($*#A``"/X%GY_^L``%#C`P``"@`PT.4P`%/C
M``!3$P0``!H*`*#A`!"@X\#T_^L`@%#B70``&N`2G^7@`I_E`1"/X```C^")
M^O_KY?3_Z]`RG^70(I_E`S"/X`0PC>7(,I_E`B"/X,2BG^7$DI_EQ(*?Y0@`
MC>4,((WE`A"@XP8@H.$%`*#A`'"-Y0,PC^#@]/_K"J"/X`F0C^`(@(_@#@``
MZOGT_^L`,)#E$0!3XP\``!K+]/_K`,"@X0%`A.("$*#C"C"@X08@H.$%`*#A
M@!&-Z!"0C>4,0(WES?3_ZP<=H.,%`*#A.O3_ZP$`<./K__\*!P"@X6;T_^L\
M`I_E!1"@X0``C^!9^O_K!0"@X7#^_^MF___J`T"@X3'__^IT]/_K@""@X0&P
M@N+M_O_J(!"=Y<@AG^4<,)WE`L"1Y_PAG^4`,)/E!`"-Y0``G.4"$*#C`B"/
MX`!PC>6/]/_K4O__ZEO^_^O8(9_E=#&?Y0(@C^`#,)+G`""3Y?0PG>4"(#/@
M`#"@XT\``!H&`*#A_-"-XO!/O>AQ]/_J)`"-Y>[^_^H<,)WE`*"3Y8#__^K.
M_?_K`*!1X@"0H.&=__^Z`+"@XPH@4.(`,,KB"`"@X0"PC>5H]/_KD!"-X@8@
MH.,(`*#A'!"-Y2WT_^L&`%#C'!"=Y34``!I#/*#CD""=Y4$S1.,#`%+ABO__
M&D@U!..T(-'A`P!2X8;__QHR(%GB`##*X@@`H.$`L(WER$"-XE'T_^LH(*#C
M"`"@X000H.$7]/_K*`!0XR```!KX,)_E^!"?Y0,PC^`$,(WE\#"?Y0$0C^`,
M$(WE!B"@X0(0H.,%`*#A"$"-Y0!PC>4#,(_@\+#-Y6/T_^N9___J'#"=Y020
MD^4``%GC5___"@D`H.$4]/_K`P!0XU/__YJD$)_E!`!`X@``B>`!$(_@;?3_
MZP``4.,)H*`!2___ZC#T_^N$`)_E``"/X&?]_^N$;@``:&X``)QO```<`0``
M!`\``+P/``#\#@``O`X``)P-``"0#@``(`$``'@.``#P:P``@`T``.0-``"H
M#0``$`P``%`,``#0"P``=`L``/P-```<#0``)`T``,@-```P"P``H`H``)`+
M```\:0``>`D````,```<"P``S`H``+@*```!RJ#C<$`MZ0S`3>#H#XSE7"*?
MY5PRG^4"((_@`S"2YPC03>(`,)/E!#"-Y0`PH.-P3QWN#6"@X3PRG^4\`I_E
M`S"?YP80H.$#4)3G``"/X&@PU>5I,,7E;?C_ZP``4.,"```*`##0Y3$`4^-E
M```*L/O_ZP@RG^4#,)_G`U"4YP`2G^4%`*#A`S"@XP$@H.,!$(_@E?/_ZP!0
M4.(,```*$""5Y>`QG^4`$)+E`S"?Y]@AG^4#`)3G`B"/X)'S_^L0,)7E`!"3
MY0@PD>4!!1/C6```&K@1G^4#,*#C`1"?YP$@H.,!`)3GJ!&?Y0$0C^!^\__K
M`%!0X@L```J8`9_E!A"@X0``C^!!^/_K`"!0XD````J$,9_E$!"5Y0,PG^<`
M$)'E`P"4YW;S_^MP,9_E<!&?Y0,PG^<!(*#C`U"4YP$0C^`%`*#A6?/_ZU@A
MG^4`$*#A`B"/X`4`H.%I\__K`""@XT0QG^5$`9_E`S"?YP80H.$#,)3G``"/
MX&D@P^4C^/_K+%&?Y0``4.,%4(_@`$"@X0@`A>41```*!QV@XP0`H.$S\__K
M`3"`XA$`4.,!`%,3)0``BOP@G^6T,)_E`B"/X`,PDN<`()/E!#"=Y0(@,^``
M,*#C&P``&@C0C>)P@+WH!`"5Y;#]_^L``%#C`$"@X0@`A>7G__\:O`"?Y0``
MC^"<\__K`3#0Y0``4^.:__\*E?__ZJ0PG^40()7E`S"/X`0PD^4``)+E`!"3
MY>GX_^N\___JB#"?Y0,PG^<#`)3G<?/_ZZ'__^IX\__K=!"?Y0`PH.$!$(_@
M;`"?Y000D>4$(*#A`!"1Y0``C^"!\__K-&<``!P!```8:```3`@``.!G``#<
M"0``K&<``+@)``!\9P``C`D``$P'```\9P``)&<``#P)``!`"0``[&8``,P&
M``!`9P``C&4``)P(``"L9@``'&8``'1F``!4"````<J@XS!`+>D,P$W@Z`^,
MY0PAG^4,,9_E`B"/X`!`H.$$`9_E`S"2YPS03>(-$*#A``"/X``PD^4$,(WE
M`#"@X[[W_^L`,%#B"@``"@`PT^4``%/C,`!3$P$PH`,`,*`3`3`CX@``5.,`
M,*`#`3`#$@``4^,*```:L""?Y:0PG^4"((_@`S"2YP`@D^4$,)WE`B`SX``P
MH.,@```:#-"-XC"`O>@`,-3E``!3X_'__PH$`*#A@/K_ZR\0H.,`4*#AWO+_
MZP``4.,!4(`2!0"@X1;S_^M8$)_E!""@XP$0C^!"\__K``!0X^+__QI$()_E
M,#"?Y0(@C^`#,)+G`""3Y00PG>4"(#/@`#"@XP,``!H$`*#A#-"-XC!`O>CM
M]__J#O/_ZV!D```<`0``L`4``/AC``#,!0``A&,```'*H.,00"WI#,!-X/@/
MC.6``*#C__+_ZPY[G^T`>X#M#GN?[0)[@.T.>Y_M!'N`[0Y[G^T&>X#M#GN?
M[0`@H.,(>X#M#7N?[7@@@.4*>X#M#'N`[1"`O>@!(T5G`````(FKS>\`````
M_MRZF`````!V5#(0`````/#ATL,````````````````!RJ#C\$<MZ0S`3>#@
M#XSE`I"@X0`PH.,`4*#A*."0Y2P`D.6)P8[@#@!<X0``T^`!0*#A,""5Y300
ME>7)#Z#A`0``*@$@DN(`$*'B+#"%Y:D^H.&`,8/A`C"3X*`>H>!X`)7E*,"%
MY0``4.,P,(7E-!"%Y3B`A0(A```:/P!9XS$``-I`D$GB*6.@X0%PAN('<X3@
M"#"@X000H.%`0(3B`."1Y03`D>4(`)'E#""1Y1`0@>($`%'A`."#Y03`@^4(
M`(/E#""#Y1`P@^+S__\:`4"@X04`H.$$]/_K!P!4X>O__QH&;6;@!I.)X`D@
MH.$'$*#A"`"@X8;R_^MXD(7E\(>]Z$!P8.()`%?A"7"@H3B`A>($$*#A!R"@
MX0``B.!\\O_K>#"5Y0,PA^!``%/C>#"%Y?"'O1@%`*#A!Y!)X`=`A.#I\__K
MR___Z@1PH.'E___J`<J@X_!!+>D,P$W@Z`^,Y7\@X.,H,)'E,&"1Y3./O^;3
M,>7G`<"#XCAP@>(X`%SC`4"@X0!0H.$V;[_F`R#'YST``-H`$*#C0"!LX@P`
MA^`N\O_K!`"@X<_S_^LX(*#C`!"@XP<`H.$H\O_K!`"@X7!@A.5T@(3EQ_/_
MZP,PU.4$`*#A`##%Y;(PU.$!,,7E`#"4Y2,TH.$",,7E`#"4Y0,PQ>4+,-3E
M!##%Y;HPU.$%,,7E"#"4Y2,TH.$&,,7E"#"4Y0<PQ>43,-3E"##%Y;(QU.$)
M,,7E$#"4Y2,TH.$*,,7E$#"4Y0LPQ>4;,-3E###%Y;HQU.$-,,7E&#"4Y2,T
MH.$.,,7E&#"4Y0\PQ>4C,-3E$##%Y;(RU.$1,,7E(#"4Y2,TH.$2,,7E(#"4
MY1,PQ>7P0;WH`_+_Z@`0H.,,`(?@."!LXO#Q_^O&___J"#"?Y0,PC^``,)/E
M2/+_ZD1A```(0"WI"("]Z`$``@`^````00````P```!!````$0```$$````G
M````00```#8```!!`````P```$$````&````00```!4```!!````#P```$$`
M```.````00```"8```!!````$P```$$````I````00````(```!!````&0``
M`$$````*````00````L```!!```````````````E<R\E<P```$1Y;F%,;V%D
M97(Z.F)O;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``````O
M<')O8R]S96QF+V5X90``+W!R;V,O)6DO)7,`97AE`"X```!005)?5$5-4```
M``!005)?4%)/1TY!344`````.@```"5S)7,E<P``+P```%!%4DPU3$E"````
M`%!%4DQ,24(`4$523#5/4%0`````4$523$E/``!005)?24Y)5$E!3$E:140`
M4$%27U-005=.140`4$%27T-,14%.````4$%27T1%0E5'````4$%27T-!0TA%
M````4$%27T=,3T)!3%]$14)51P````!005)?1TQ/0D%,7U1-4$1)4@```%!!
M4E]435!$25(``%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.````
M`#$```!L<V5E:R!F86EL960`````<F5A9"!F86EL960`3$1?3$E"4D%265]0
M051(`%-94U1%30``)3`R>``````E<R5S)7,E<P````!P87(M`````"5S.B!C
M<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R
M<FYO/25I*0H``"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A
M9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N
M*0H``%!!5$@`````<&%R;``````N<&%R`````'-H;W)T(')E860``"5S)7-C
M86-H92TE<R5S```E<R5S=&5M<"TE=25S````)7,E<W1E;7`M)74M)74E<P``
M```8````<&5R;``````P````4$%2.CI086-K97(Z.E9%4E-)3TX`````,2XP
M-C,```!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0`````E<SH@
M8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I
M;&5D("AE<G)N;STE:2D*`````"UE```M+0``979A;"`G97AE8R`O=7-R+V)I
M;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@
M=6YD97(@<V]M92!S:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)%!!4E]-
M04=)0RP@)$9)3$5?;V9F<V5T7W-I>F4L("1C86-H95]N86UE7W-I>F4I.PI"
M14=)3B!["B1005)?34%'24,@/2`B7&Y005(N<&U<;B(["B1&24Q%7V]F9G-E
M=%]S:7IE(#T@-#L@("`C('!A8VLH(DXB*0HD8V%C:&5?;F%M95]S:7IE(#T@
M-#`["B102UI)4%]-04=)0R`](")02UPP,#-<,#`T(CL*?0IS=6(@9FEN9%]P
M87)?;6%G:6,*>PIM>2`H)&9H*2`]($!?.PIM>2`D8VAU;FM?<VEZ92`](#8T
M("H@,3`R-#L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D9F@["FUY("1P;W,@
M/2`H)'-I>F4M,2D@+2`H)'-I>F4M,2D@)2`D8VAU;FM?<VEZ93L@("`@("`C
M($Y/5$4Z("1P;W,@:7,@82!M=6QT:7!L92!O9B`D8VAU;FM?<VEZ90IW:&EL
M92`H)'!O<R`^/2`P*2!["G-E96L@)&9H+"`D<&]S+"`P.PIR96%D("1F:"P@
M)&)U9BP@)&-H=6YK7W-I>F4@*R!L96YG=&@H)%!!4E]-04=)0RD["FEF("@H
M;7D@)&D@/2!R:6YD97@H)&)U9BP@)%!!4E]-04=)0RDI(#X](#`I('L*<F5T
M=7)N("1P;W,@*R`D:3L*?0HD<&]S("T]("1C:'5N:U]S:7IE.PI]"G)E='5R
M;B`M,3L*?0IM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE+"`E
M36]D=6QE0V%C:&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E
M<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q
M=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z
M.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<5M296UO=FEN9R!F:6QE<R!I
M;B`B)'!A<E]T96UP(ETI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@
M*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@
M)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS
M,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]/B`G
M=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O
M<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIM>2`D
M9FEL96YA;64@/2`D=&UP+3YF:6QE;F%M93L*<')I;G0@)'1M<"`\/"(N+BXB
M.PIX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?
M=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I
M"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<D9FEL96YA;64G
M"BXN+@IC;&]S92`D=&UP.PIC:&UO9"`P-S`P+"`D9FEL96YA;64["FUY("1C
M;60@/2`B)&9I;&5N86UE(#XO9&5V+VYU;&P@,CXF,2`F(CL*<WES=&5M*"1C
M;60I.PIO=71S*'%Q6U-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E
M<F9O<FT@8VQE86YU<#H@)&9I;&5N86UE72D["GT*?2!]"D)%1TE.('L*26YT
M97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!
M4CHZ0D]/5#L*979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U:65T(#T@
M(21%3E9[4$%27T1%0E5'?3L*;7D@)7-Y<R`]("@*<&%T:%]S97`@("`@/3X@
M*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^
M("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G
M)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<
M)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*;W5T<RAQ<5M<)'!R;V=N
M86UE(#T@(B1P<F]G;F%M92)=*3L*7W-E=%]P87)?=&5M<"@I.PIO=71S*'%Q
M6UPD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2)=*3L*;7D@*"1S
M=&%R=%]P;W,L("1S=&%R=%]O9E]&24Q%7W-E8W1I;VXI.PI-04=)0SH@>PIL
M;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*=6YL97-S("AO<&5N(%]&
M2"P@)SPZ<F%W)RP@)'!R;V=N86UE*2!["F]U=',H<7%;0V%N)W0@<F5A9"!F
M<F]M(&9I;&4@(B1P<F]G;F%M92)=*3L@(",@9&]N)W0@=7-E("0A(&AE<F4@
M87,@:70@<F5Q=6ER97,@17)R;F\N<&T*;&%S="!-04=)0SL*?0IM>2`D;6%G
M:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H*E]&2"D["FEF("@D;6%G:6-?<&]S
M(#P@,"D@>PIO=71S*'%Q6T-A;B=T(&9I;F0@;6%G:6,@<W1R:6YG("(D4$%2
M7TU!1TE#(B!I;B!F:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,["GT*
M;W5T<R@B1F]U;F0@4$%2(&UA9VEC(&%T('!O<VET:6]N("1M86=I8U]P;W,B
M*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92`M
M(&QE;F=T:"@B7#!#04-(12(I+"`P.PIR96%D(%]&2"P@)&)U9BP@;&5N9W1H
M*")<,$-!0TA%(BD["FEF("@D8G5F(&YE(")<,$-!0TA%(B`F)B`D8G5F(&YE
M(")<,$-,14%.(BD@>PIO=71S*").;R!C86-H92!M87)K97(@9F]U;F0B*3L*
M;&%S="!-04=)0SL*?0IO=71S*'%Q6T-A8VAE(&UA<FME<B`B)&)U9B(@9F]U
M;F1=*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ
M92P@,#L*<F5A9"!?1D@L("1B=68L("1&24Q%7V]F9G-E=%]S:7IE.PIM>2`D
M;V9F<V5T(#T@=6YP86-K*").(BP@)&)U9BD["F]U=',H(D]F9G-E="!F<F]M
M('-T87)T(&]F($9)3$5S(&ES("1O9F9S970B*3L*<V5E:R!?1D@L("1M86=I
M8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92`M("1O9F9S970L(#`["B1S=&%R
M=%]O9E]&24Q%7W-E8W1I;VX@/2!T96QL(%]&2#L*;7D@)7)E<75I<F5?;&ES
M=#L*<F5A9"!?1D@L("1B=68L(#0[("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(R!R96%D('1H92!F:7)S="`B1DE,12(*=VAI;&4@*"1B=68@97$@(D9)
M3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP
M86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U=',H<7%;
M56YP86-K:6YG($9)3$4@(B1F=6QL;F%M92(N+BY=*3L*;7D@)&-R8R`]("@@
M)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E
M9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_
M*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B
M=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@
M)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I;&5N86UE
M(#T@7W-A=F5?87,H(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE
M879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ
M2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L
M<V4@>PHD36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L
M"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*)')E<75I<F5?
M;&ES='LD9G5L;&YA;65]*RL["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C
M86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E
M='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&EN9F\@/2`D
M36]D=6QE0V%C:&5[)&UO9'5L97T["G)E='5R;B!U;FQE<W,@)&EN9F\["F1E
M;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5].PHD24Y#>R1M;V1U;&5](#T@
M(B]L;V%D97(O)&EN9F\O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@
M86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&
M:6QE+3YN97=?=&UP9FEL92!O<B!D:64@(D-A;B=T(&-R96%T92!T96UP(&9I
M;&4Z("0A(CL*)&9H+3YB:6YM;V1E*"D["B1F:"T^<')I;G0H)&EN9F\M/GMB
M=69]*3L*)&9H+3YS965K*#`L(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM
M>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&EN9F\M/GMC<F-]+G!M(BP@)&EN
M9F\M/GMB=69]*3L*)&EN9F\M/GMF:6QE?2`]("1F:6QE;F%M93L*;W!E;B!M
M>2`D9F@L("<\.G)A=R<L("1F:6QE;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A
M9"`B)&9I;&5N86UE(CH@)"%=.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T
M<F%P<&EN9R!F86EL960Z(&-A;B=T(&9I;F0@;6]D=6QE("1M;V1U;&4A(CL*
M?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V
M>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A
M=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)
M3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E
M<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@
M)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN
M<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I
M;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L
M)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]"FEF
M("@D8G5F(&YE("102UI)4%]-04=)0RD@>PIO=71S*'%Q6TYO('II<"!F;W5N
M9"!A9G1E<B!&24Q%('-E8W1I;VX@:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL
M87-T($U!1TE#(#L*?0HD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0[("`@
M("`@("`@("`@("`@(",@<W1A<G0@;V8@>FEP"GT*;7D@0'!A<E]A<F=S.PIM
M>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T
M92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M87D@
M8F4@82!S96-U<FET>2!P<F]B;&5M*0II9B`H(21S=&%R=%]P;W,@;W(@*"1!
M4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I
M<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*
M=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R
M"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H
M:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8[
M"GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?
M:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB
M<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H
M($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@
M(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?
M87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*
M96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF
M("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E
M<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P
M96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@<7%;0V%N)W0@;W!E;B!L;V<@
M9FEL92`B)#(B.B`D(5T["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?
M;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES
M=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN
M8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH
M*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@
M0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]
M"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R
M8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D<&%R(#T@
M<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P
M96X@;7D@)&9H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!F:6YD
M('!A<B!F:6QE("(D<&%R(CH@)"%=.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I
M.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&
M:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I
M("D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P87(B
M73L*?0IM>2`E;65T85]P87(@/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D;65T
M82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O
M+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@
M+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FEF("AD969I;F5D("1P87(I
M('L*;W!E;B!M>2`D<&@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T
M(')E860@<&%R(&9I;&4@(B1P87(B.B`D(5T["FUY("1B=68["G)E860@)'!H
M+"`D8G5F+"`T.PID:64@<7%;(B1P87(B(&ES(&YO="!A('!A<B!F:6QE72!U
M;FQE<W,@)&)U9B!E<2`D4$M:25!?34%'24,["F-L;W-E("1P:#L*?0I#<F5A
M=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U="P*
M24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U)$5U(H*2!\($E/
M.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE('%Q6T-A;B=T(&-R
M96%T92!F:6QE("(D;W5T(CH@)"%=.PHD9F@M/F)I;FUO9&4H*3L*<V5E:R!?
M1D@L(#`L(#`["FUY("1L;V%D97(["FEF("AD969I;F5D("1S=&%R=%]O9E]&
M24Q%7W-E8W1I;VXI('L*<F5A9"!?1D@L("1L;V%D97(L("1S=&%R=%]O9E]&
M24Q%7W-E8W1I;VX["GT@96QS92!["FQO8V%L("0O(#T@=6YD968["B1L;V%D
M97(@/2`\7T9(/CL*?0II9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO
M861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E
M<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1L
M;V%D97(L("0P*3L*?0HD9F@M/G!R:6YT*"1L;V%D97(I"F]R(&1I92!Q<5M%
M<G)O<B!W<FET:6YG(&QO861E<B!T;R`B)&]U="(Z("0A73L*:68@*"1B=6YD
M;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D
M>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM
M>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N
M92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X
M<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@
M0$E.0SL*<WPO*WPO?&<L('-\+R1\?"!F;W)E86-H($!I;F,["FUY("5F:6QE
M<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B
M:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O
M;F9I9WML:6)?97AT?3L@("`@("`@("`C(%A86"!L:6)?97AT('9S(&1L97AT
M(#\*;7D@)7=R:71T96X["F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5F
M:6QE<RD@>PIM>2`H)&9I;&4L("1N86UE*3L*:68@*&1E9FEN960H;7D@)&9C
M(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD:V5Y?2DI('L**"1F:6QE+"`D
M;F%M92D@/2`H)&ME>2P@)&9C*3L*?0IE;'-E('L*9F]R96%C:"!M>2`D9&ER
M("A`:6YC*2!["FEF("@D:V5Y(#U^(&U\7EQ1)&1I<EQ%+R@N*BDD?&DI('L*
M*"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)#$I.PIL87-T.PI]"FEF("@D:V5Y
M(#U^(&U\7B]L;V%D97(O6UXO72LO*"XJ*21\*2!["FEF("AM>2`D<F5F(#T@
M)$UO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D<F5F+"`D
M,2D["FQA<W0["GT*:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE
M*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*?0IN97AT('5N;&5S
M<R!D969I;F5D("1N86UE.PIN97AT(&EF("1W<FET=&5N>R1N86UE?2LK.PIN
M97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT
M7$4D+VD["F]U=',H<W!R:6YT9BAQ<5M086-K:6YG($9)3$4@(B5S(BXN+ETL
M(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92DI.PIM>2`D8V]N
M=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U
M9GT["GT*96QS92!["FQO8V%L("0O(#T@=6YD968["F]P96X@;7D@)'1H+"`G
M/#IR87<G+"`D9FEL92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&4B.B`D
M(5T["B1C;VYT96YT(#T@/"1T:#X["F-L;W-E("1T:#L*4$%2.CI&:6QT97(Z
M.E!O9%-T<FEP+3YA<'!L>2A<)&-O;G1E;G0L("(\96UB961D960^+R1N86UE
M(BD*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z
M<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M
M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0HD9F@M/G!R:6YT
M*")&24Q%(BP*<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2P*<W!R:6YT
M9B@B)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT
M96YT*2P@)&YA;64I+`IP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DL"B1C
M;VYT96YT*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!E;6)E9&1E9"!&24Q%
M('1O("(D;W5T(CH@)"%=.PIO=71S*'%Q6U=R:71T96X@87,@(B1N86UE(ETI
M.PI]"GT*:68@*"1Z:7`I('L*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H
M*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+"F]R(&1I92!Q<5M%<G)O<B!W<FET
M:6YG('II<"!P87)T(&]F("(D;W5T(ET["GT*:68@*"1M971A7W!A<GMC;&5A
M;GTI('L*)&9H+3YP<FEN="@B7#!#3$5!3B(I.PI]"F5L<V4@>PII9B`H(61E
M9FEN960@)&-A8VAE7VYA;64I('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN
M97<H,2D["G-E96L@)&9H+"`P+"`P.PHD8W1X+3YA9&1F:6QE*"1F:"D["G-E
M96L@)&9H+"`P+"`R.PHD8V%C:&5?;F%M92`]("1C='@M/FAE>&1I9V5S=#L*
M?0HD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@)&-A8VAE
M7VYA;65?<VEZ93L*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@D8V%C:&5?;F%M
M95]S:7IE("T@;&5N9W1H("1C86-H95]N86UE*3L*)&9H+3YP<FEN="@D8V%C
M:&5?;F%M92P*(EPP0T%#2$4B*3L*?0IM>2`D;V9F<V5T(#T@)&9H+3YT96QL
M("T@;&5N9W1H*"1L;V%D97(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D;V9F
M<V5T*2P*)%!!4E]-04=)0RD["B1F:"T^8VQO<V4@;W(@9&EE('%Q6T5R<F]R
M('=R:71I;F<@=')A:6QE<B!O9B`B)&]U="(Z("0A73L*8VAM;V0@,#<U-2P@
M)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O
M<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ
M7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q
M=6ER92!!<F-H:79E.CI::7`["GT*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(",@07)C:&EV93HZ6FEP(&]P
M97)A=&5S(&]N(&%N($E/.CI(86YD;&4*)&9H+3YF9&]P96XH9FEL96YO*%]&
M2"DL("=R)RD@;W(@9&EE('%Q6V9D;W!E;B@I(&9A:6QE9#H@)"%=.PI!<F-H
M:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M<R!?1D@I.PIM>2`D>FEP(#T@07)C
M:&EV93HZ6FEP+3YN97<["B@D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H
M+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2D*;W(@9&EE
M('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P<F]G;F%M92)=.PI!
M<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@V-"`J(#$P,C0I.PIP=7-H($!0
M05(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O9VYA;65]
M(#T@)'II<#L*;W5T<R@B17AT<F%C=&EN9R!Z:7`N+BXB*3L*:68@*&1E9FEN
M960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@
M<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2![
M"FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M
M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA
M;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA
M;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM
M>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]4
M14U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE("8F("US
M(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H<7%;
M4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES
M=',@870@(B1D97-T7VYA;64B72D["GT@96QS92!["F]U=',H<7%;17AT<F%C
M=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(N+BY=*3L**"1M
M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*2`]/2!!<F-H
M:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!E>'1R86-T:6YG
M('II<"!M96UB97(@=&\@(B1D97-T7VYA;64B73L*8VAM;V0H,#4U-2P@)&1E
M<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"10
M05(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@
M0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-
M;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM
M8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@
M/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E
M4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M
M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA
M;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z
M.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P
M871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?
M;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E
M<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN
M9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z
M.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V
M>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&
M:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D
M97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I
M<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@
M07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PIR97%U:7)E(%!!
M4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q
M=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT
M97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L('L@
M<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*979A;"![
M(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E($%R8VAI
M=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z
M.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I
M<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@=71F."!].PI]
M"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM005)?5$5-
M4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@
M/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[
M)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I
M*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D969I
M;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R
M;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^
M*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN
M3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L
M<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U:60["GT*
M96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%
M4GT@?'P@)U-94U1%32<["GT*;7D@)'-T;7!D:7(@/2`B)'!A=&@D<WES>U]D
M96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T
M;7!D:7(L(#`W-34["FUY("1C86-H95]D:7(["FEF("@D14Y6>U!!4E]#3$5!
M3GTI('L*)&-A8VAE7V1I<B`](")T96UP+20D(CL*?0IE;'-E('L*;W!E;B!M
M>2`D9F@L("(\.G)A=R(L("1P<F]G;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A
M9"`B)'!R;V=N86UE(CH@)"%=.PII9B`H*&UY("1M86=I8U]P;W,@/2!F:6YD
M7W!A<E]M86=I8R@D9F@I*2`^/2`P*2!["G-E96L@)&9H+"`D;6%G:6-?<&]S
M"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*
M;7D@)&)U9CL*<F5A9"`D9F@L("1B=68L(&QE;F=T:"@B7#!#04-(12(I.PII
M9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("1M86=I8U]P;W,*
M+2`D1DE,15]O9F9S971?<VEZ90HM(&QE;F=T:"@B7#!#04-(12(I"BT@)&-A
M8VAE7VYA;65?<VEZ92P@,#L*<F5A9"`D9F@L("1B=68L("1C86-H95]N86UE
M7W-I>F4["B1B=68@/7X@<R]<,"\O9SL*)&-A8VAE7V1I<B`](")C86-H92TD
M8G5F(CL*?0I]"F-L;W-E("1F:#L*?0II9B`H(21C86-H95]D:7(I('L*)&-A
M8VAE7V1I<B`](")T96UP+20D(CL*)$5.5GM005)?0TQ%04Y](#T@,3L*?0HD
M<W1M<&1I<B`N/2`B)'-Y<WM?9&5L:6U])&-A8VAE7V1I<B(["FUK9&ER("1S
M=&UP9&ER+"`P-S4U.PHD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIL87-T
M.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6
M>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]S879E7V%S('L*;7D@*"1N
M86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA;64@/2`B
M)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L;&YA;64I('L*;7D@
M)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"(["FUY("1F:#L**&]P96X@)&9H
M+"`G/CIR87<G+"`D=&5M<&YA;64I"B8F("AP<FEN="`D9F@@)&-O;G1E;G1S
M*0HF)B`H8VQO<V4@)&9H*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R`B)'1E
M;7!N86UE(CH@)"%=.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN
M960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL
M:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E
M=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A
M;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@
M/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@
M86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*
M)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M
M92P@)'-Y<WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!
M345](&]R(&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`^/2`P*2![
M"FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N(&EF
M("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921S>7-[7V5X97TB*2!["B1P
M<F]G;F%M92`N/2`D<WES>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H(&UY
M("1D:7(@*'-P;&ET("]<421S>7-[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]
M*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q
M("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D<WES>U]D96QI;7U<120O
M+SL**"@D<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S
M>7-[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O
M9VYA;64D<WES>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E
M;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1S>7-[7V1E;&EM
M?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R
M;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O
M9VYA;64L("1S>7-[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)'-Y
M<WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W
M9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R
M.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D
M<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D<WES>U]D96QI;7U<
M12DO)'!W9"1S>7-[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P
M<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?
M24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6
M>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-
M4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12`I("D@>PID96QE=&4@)$5.
M5GLB4$%27R1?(GT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"
M54<@+RD@>PHD14Y6>R)005)?)%\B?2`]("1%3E9[(E!!4E]'3$]"04Q?)%\B
M?2!I9B!E>&ES=',@)$5.5GLB4$%27T=,3T)!3%\D7R)].PI]"FEF("@D14Y6
M>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"GT*<W5B
M(&]U=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT
M("1L;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U
M8B!I;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@
M9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB
M97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A
M<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER
M92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM
M<&]R="A`<&%R7V%R9W,I.PID:64@<7%;<&%R+G!L.B!#86XG="!O<&5N('!E
M<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T
M;W)Y7&Y="G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]2
M13HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*
M9&EE("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]2
M13HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD
M*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.
M1%]?"@!54T52`````%5315).04U%`````%1%35!$25(`5$U0`"]T;7``````
M<&5R;'AS:2YC`````$-!0TA%```^````00````P```!!````$0```$$````G
M````00```#8```!!`````P```$$````&````00```!4```!!````#P```$$`
M```.````00```"8```!!````$P```$$````I````00````(```!!````&0``
M`$$````*````00````L```!!``````````````"!L@&!L+"L!P````"&L@&!
ML+"K#P````"@L@&!L+"O!P````"!L@&!L+"J!P````"$`@&!L`^Q``````"%
ML@&!L+"N?P````"PA_]_L*H)@'"*_W\!````X(O_?Z\FLH!DF/]_L+"N@$29
M_W^PJ!N`[)G_?["K'H!LF_]_L*@#@`R<_W]\__]_/)W_?["O`H"`G_]_L+`!
M@,R?_W]P__]_W*#_?["PL(#8H/]_;/__?V"C_W^PL*B`B*/_?VC__W\HI?]_
ML*H!@&2J_W\`A`*`_*K_?US__W]HJ_]_8/__?R2M_W^PL*B`0*W_?["K!H!P
MKO]_L*\^@+BU_W^PJ@&`A+C_?["I`H"XN?]_L+"H@#BZ_W^PL*Z`A+O_?["P
MK(#,O/]_L+"P@-B\_W\!````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````^!P``(0<```!
M````2P,```$```!6`P```0```&`#```!````=`,``!T```#\!```#````-`5
M```-````R$X``!D```"DK0``&P````0````:````J*T``!P````$````!```
M`+0!``#U_O]O[`0```4```"(#```!@```-@%```*````-P4```L````0````
M%0`````````#````S*X```(```#@`0``%````!$````7````\!,``!$````8
M$P``$@```-@````3````"````!X````(````^___;P$```C^__]OF!(``/__
M_V\#````\/__;\`1``#Z__]O#@``````````````````````````````````
M``````````````````````"LK0````````````#<%0``W!4``-P5``#<%0``
MW!4``-P5``#<%0``W!4``-P5``#<%0``W!4``-P5``#<%0``W!4``-P5``#<
M%0``W!4``-P5``#<%0``W!4``-P5``#<%0``W!4``-P5``#<%0``W!4``-P5
M``#<%0``W!4``-P5``#<%0``W!4``-P5``#<%0``W!4``-P5``#<%0``W!4`
M`-P5``#<%0``W!4``-P5``#<%0``W!4``-P5``#<%0``W!4``-P5``#<%0``
MW!4``-P5``#<%0``W!4``-P5``#<%0``W!4``-P5``#<%0``W!4``-P5````
M````````````````````````````````````````````````````````````
M````````P!@````````$L```"E!!4BYP;0H`````')```,!/````````@%``
M`(10```0D```R$\``!B0````````_(\```20````````C%(``$=#0SH@*%-5
M4T4@3&EN=7@I(#$S+C(N,2`R,#(T,#4P.2!;<F5V:7-I;VX@8C=A,C8Y-S<S
M,V0Q.6$P.3-C8F1D,&4R,#!F9F-E,#8Y831B8S@Q,ET`03(```!A96%B:0`!
M*`````4W+4$`!@H'00@!"0(*!!($$P$4`14!%P,8`1D!&@(<`2(!`"YS:'-T
M<G1A8@`N:6YT97)P`"YN;W1E+F=N=2YB=6EL9"UI9``N;F]T92Y!0DDM=&%G
M`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N
M=F5R<VEO;E]R`"YR96PN9'EN`"YR96PN<&QT`"YI;FET`"YT97AT`"YF:6YI
M`"YR;V1A=&$`+D%232YE>'1A8@`N05)-+F5X:61X`"YE:%]F<F%M90`N:6YI
M=%]A<G)A>0`N9FEN:5]A<G)A>0`N9'EN86UI8P`N9V]T`"YD871A`"YB<W,`
M+F-O;6UE;G0`+D%232YA='1R:6)U=&5S````````````````````````````
M```````````````````````````````+`````0````(```!4`0``5`$``!D`
M``````````````$`````````$P````<````"````<`$``'`!```D````````
M```````$`````````"8````'`````@```)0!``"4`0``(```````````````
M!``````````X````!0````(```"T`0``M`$``#@#```&``````````0````$
M````-````/;__V\"````[`0``.P$``#L````!@`````````$````!````#X`
M```+`````@```-@%``#8!0``L`8```<````#````!````!````!&`````P``
M``(```"(#```B`P``#<%``````````````$`````````3@```/___V\"````
MP!$``,`1``#6````!@`````````"`````@```%L```#^__]O`@```)@2``"8
M$@``@`````<````#````!`````````!J````"0````(````8$P``&!,``-@`
M```&``````````0````(````<P````D```!"````\!,``/`3``#@`0``!@``
M`!<````$````"````'P````!````!@```-`5``#0%0``#```````````````
M!`````````!W`````0````8```#<%0``W!4``.0"``````````````0````$
M````@@````$````&````P!@``,`8```(-@`````````````(`````````(@`
M```!````!@```,A.``#(3@``"```````````````!`````````".`````0``
M``(```#03@``T$X``/A!``````````````0`````````E@````$````"````
MR)```,B0``!(```````````````$`````````*$````!``!P@@```!"1```0
MD0``Z`````X`````````!`````````"L`````0````(```#XD0``^)$```0`
M``````````````0`````````M@````X````#````I*T``*2=```$````````
M```````$````!````,(````/`````P```*BM``"HG0``!```````````````
M!`````0```#.````!@````,```"LK0``K)T``"`!```'``````````0````(
M````UP````$````#````S*X``,R>```T`0`````````````$````!````-P`
M```!`````P````"P````H```2```````````````!`````````#B````"```
M``,```!(L```2*```!0```````````````0`````````YP````$````P````
M`````$B@``!6```````````````!`````0```/`````#``!P``````````">
MH```,P```````````````0`````````!`````P``````````````T:`````!
2``````````````$`````````
